@@ -1041,18 +1041,43 @@ class SMDB():
     def series_dbFilesCount(self, str_SeriesInstanceUID, str_type) -> dict:
         """
         Return the number of actual str_type files by "counting" the
-        object json files for a given series.
+        object json files for a given series <str_type>.
+
+        In the case of success, the return count will reflect the number
+        of current data objects relevant to the <str_type>. This is deter-
+        mined by checking if the table has an 'objectCounter' element. If
+        this element exists, the return count will be set to the value of  
+        'objectCounter.current'. If the 'objectCounter' is not an element
+        in the <str_type> db, the return count will then be set simply to
+        self.series_packedFilesCount() so to be consistent in a status
+        line with the return count of the retrieve/pack/DCM counts.
+
+        Return count can be one of four values:
+        1. Packed files exist, but the downstream job was never attempted. In
+           this case the return count is set to 0.
+        2. The downstream job was attempted and had no error, but some error
+           occurred in counting the packed files, in which case the count is
+           set to -1. This is a largely impossible edge case, but added for
+           completeness' sake.
+        3. Packed files exist, the downstream job was attempted but failed. In
+           this case the return count is set to -10. Typically this indicates
+           some issue with the remote swift service.
+        4. Packed files exist, the downstream job was attempted and succeeded.
+           In this case the return count is set to the 'objectCounter.current'
+           value or the packed count.
 
-        Note this returns the count in the seriesDataDir for a given
-        series, which assumes that a file has been processed and
-        recorded -- this does not return the count of files in the
-        packed location.
         """
         b_status            : bool  = False
+        d_content           : dict  = {}
         count               : int   = 0
         l_files             : list  = []
         str_seriesDir       : str   = os.path.join( self.args.str_logDir,
                                                     self.str_seriesData)
+        str_dbFile          : str   = '%s/%s-%s.json' % (
+                                                str_seriesDir,
+                                                str_SeriesInstanceUID,
+                                                str_type
+                                        )
         if os.path.isdir(str_seriesDir):
             l_files         : list  = [
                 f for f in os.listdir(str_seriesDir)
@@ -1061,16 +1086,36 @@ class SMDB():
             b_status        = bool(len(l_files))
             if b_status:
                 """
-                A true status simply indicates the entire series has been processed.
-                In order to remain consistent with the other count measures, we set
-                the 'count' to number of packed files.
+                A 'true' status simply indicates the entire series has been pro-
+                cessed, since a single json file would have been created. This
+                file contains further information on the success (or not) of
+                the operation, hence this db file is examined to provide a
+                more meaningful return measure.
+
+                In the case of success, the final return file count can be an
+                incremental-in-process count (say for a 'register' operation,
+                or simply the total number of packed files for the case of a
+                'push' operation).
                 """
-                d_packed    = self.series_packedFilesCount(str_SeriesInstanceUID)
-                if d_packed['status']:
-                    count       = d_packed['count']
-                else:
-                    b_status    = False
-                    count       = -1
+                count       = len(l_files)
+                if count == 1:
+                    with open(str_dbFile) as fj:
+                        self.json_read(fj, d_content)
+                    if 'status' in d_content:
+                        if not d_content['status']:
+                            count       = -10
+                    if count != -10:
+                        if 'objectCounter' in d_content:
+                            if 'current' in d_content['objectCounter']:
+                                count   = d_content['objectCounter']['current']
+                        else:
+                            d_packed    = self.series_packedFilesCount(str_SeriesInstanceUID)
+                            count       = d_packed['count']
+                            if d_packed['status']:
+                                count       = d_packed['count']
+                            else:
+                                b_status    = False
+                                count       = -1
         return {
             'status'    : b_status,
             'count'     : count
@@ -1252,6 +1297,7 @@ class SMDB():
             Return False if no updates made, else True
             """
             b_updatesMade   : bool  = False
+            b_status        : bool  = False
             try:
                 if self.d_seriesImage[self.d_DICOM['SeriesInstanceUID']]['outputFile'] not in                                      \
                     self.d_seriesImage[self.d_DICOM['SeriesInstanceUID']]           \
@@ -1271,12 +1317,15 @@ class SMDB():
                     b_updatesMade   = True
                 else:
                     self.d_seriesModel     = self.d_seriesImage[self.d_DICOM['SeriesInstanceUID']]
+                b_status        = True
             except:
                 # pudb.set_trace()
                 b_updatesMade   = False
+                b_status        = False
             return {
-                'status'    : b_updatesMade,
-                'image'     : self.d_seriesImage
+                'status'        : b_status,
+                'updatesMade'   : b_updatesMade,
+                'image'         : self.d_seriesImage
             }
 
         def seriesData_singleImageFile_save(d_update)  -> dict:
@@ -1400,7 +1449,6 @@ class SMDB():
         directory locations that correspond to the search parameters of
         **kwargs.
         """
-        pudb.set_trace()
         d_ret                   : dict  = {}
         str_seriesInstanceUID   : str   = ""
         if len(self.args.SeriesInstanceUID):
@@ -1412,6 +1460,12 @@ class SMDB():
         """
         Return a structure that contains a list of all directories containing
         DICOM files for a given PatientID.
+
+        Technical debt warning!
+        This method makes some _implicit_ assumptions on the series name,
+        most notably that the series name in the studyDir ends in "-meta"
+        (or -<string>). This trailing "-meta" is removed during processing
+        in this method.
         """
         d_ret               : dict  = {}
         b_status            : bool  = False
@@ -1426,6 +1480,7 @@ class SMDB():
         str_imageLocation   : str   = ""
         str_imageDataDir    : str   = ""
         str_imageDir        : str   = ""
+        seriesCount         : int   = 0
 
         if os.path.isfile(str_patientDataFile):
             with open(str_patientDataFile) as fp:
@@ -1433,21 +1488,25 @@ class SMDB():
             fp.close()
             l_studies       = d_patientData[astr_PatientID]['StudyList']
             for study in l_studies:
-                d_series[study] = [os.path.splitext(f)[0] for f in os.listdir(
+                d_series[study] = [os.path.splitext(f)[0].rsplit('-', 1)[0] for f in os.listdir(
                                                 '%s/%s-series' % (self.str_studyDataDir, study)
                                                         )]
                 d_imageDirs[study]  = []
+                seriesCount         = 0
                 for series in d_series[study]:
+                    series              = series.rsplit('-', 1)[0]
                     str_imageDataDir    = '%s/%s-img' % (self.str_seriesDataDir, series)
                     str_imageFile       = os.listdir(str_imageDataDir)[0]
                     if os.path.isfile('%s/%s' % (str_imageDataDir, str_imageFile)):
                         with open('%s/%s' % (str_imageDataDir, str_imageFile)) as fp:
                             self.json_read(fp, d_imageInfo)
                         fp.close()
+                        d_series[study][seriesCount] = d_imageInfo
                         str_imageObj        = os.path.splitext(str_imageFile)[0]
                         str_imageLocation   = d_imageInfo[series]['imageObj'][str_imageObj]['FSlocation']
                         str_imageDir        = os.path.dirname(str_imageLocation)
                         d_imageDirs[study].append(str_imageDir)
+                        seriesCount         += 1
                 b_status    = True
 
         d_ret = {
